@@ -1,3 +1,4 @@
+from __future__ import print_function
 from pyfasta import Fasta
 import operator
 import collections
@@ -13,16 +14,16 @@ def newnames(oldname, n, kmers=None, overlap=None, header=None):
     ['some.split.fasta']
 
     >>> newnames('some.fasta', 2)
-    ['some.a.fasta', 'some.b.fasta']
+    ['some.0.fasta', 'some.1.fasta']
 
     >>> newnames('some', 2)
-    ['some.a', 'some.b']
+    ['some.0', 'some.1']
 
     >>> newnames('some.fasta', 2, kmers=1000)
-    ['some.a.1Kmer.fasta', 'some.b.1Kmer.fasta']
+    ['some.0.1Kmer.fasta', 'some.1.1Kmer.fasta']
 
     >>> newnames('some.fasta', 2, kmers=10000, overlap=2000)
-    ['some.a.10Kmer.2Koverlap.fasta', 'some.b.10Kmer.2Koverlap.fasta']
+    ['some.0.10Kmer.2Koverlap.fasta', 'some.1.10Kmer.2Koverlap.fasta']
 
     >>> newnames('some.fasta', 1, kmers=100000, overlap=2000)
     ['some.split.100Kmer.2Koverlap.fasta']
@@ -47,8 +48,8 @@ def newnames(oldname, n, kmers=None, overlap=None, header=None):
     else:
         width = len(str(n))
         names = [pattern % str(i).rjust(width, '0') for i in range(n)]
-    print >>sys.stderr, "creating new files:"
-    print >>sys.stderr, "\n".join(names)
+    print("creating new files:", file=sys.stderr)
+    print("\n".join(names), file=sys.stderr)
     return names
 
 
@@ -57,8 +58,8 @@ def print_to_fh(fh, fasta, lens, seqinfo):
     lens[fh.name] += seqlen
     f = fasta
     assert len(str(f[key])) == seqlen, (key, seqlen, len(str(f[key])))
-    print >>fh, ">%s" % key
-    print >>fh, str(f[key])
+    print(">%s" % key, file=fh)
+    print(str(f[key]), file=fh)
 
 
 def format_kmer(seqid, start):
@@ -74,7 +75,7 @@ def split(args):
     parser = optparse.OptionParser("""\
    split a fasta file into separated files.
         pyfasta split -n 6 [-k 5000 ] some.fasta
-    the output will be some.1.fasta, some.2.fasta ... some.6.fasta
+    the output will be some.0.fasta, some.1.fasta ... some.6.fasta
     the sizes will be as even as reasonable.
    """)
     parser.add_option("--header", dest="header", metavar="FILENAME_FMT",
@@ -108,7 +109,7 @@ def split(args):
     if options.header:
         names = dict([(seqid, options.header % \
                       dict(fasta=f.fasta_name, seqid=seqid)) \
-                                       for seqid in f.keys()])
+                                       for seqid in f.iterkeys()])
         """
         if len(names) > 0:
             assert names[0][1] != names[1][1], ("problem with header format", options.header)
@@ -131,27 +132,28 @@ def with_header_names(f, names):
     split the fasta into the files in fhs by headers.
     """
     for seqid, name in names.iteritems():
-        fh = open(name, 'wb')
-        print >>fh, ">%s" % seqid
-        print >>fh, str(f[seqid])
-        fh.close()
+        with open(name, 'w') as fh:
+            print(">%s" % seqid, file=fh)
+            print(str(f[seqid]), file=fh)
 
 def with_kmers(f, names, k, overlap):
     """
-    split the sequences in Fasta object `f` into pieces of length `k` 
+    split the sequences in Fasta object `f` into pieces of length `k`
     with the given `overlap` the results are written to the array of files
     `fhs`
     """
-    fhs = [open(name, 'wb') for name in names]
+    fhs = [open(name, 'w') for name in names]
     i = 0
-    for seqid in f.keys():
+    for seqid in f.iterkeys():
         seq = f[seqid]
         for (start0, subseq) in Fasta.as_kmers(seq, k, overlap=overlap):
 
             fh = fhs[i % len(fhs)]
-            print >>fh, ">%s" % format_kmer(seqid, start0)
-            print >>fh, subseq
+            print(">%s" % format_kmer(seqid, start0), file=fh)
+            print(subseq, file=fh)
             i += 1
+    for fh in fhs:
+        fh.close()
 
 def without_kmers(f, names):
     """
@@ -159,9 +161,9 @@ def without_kmers(f, names):
     but attempts to distribute the sequences in Fasta object `f` evenly
     among the file handles in fhs.
     """
-    fhs = [open(name, 'wb') for name in names]
+    fhs = [open(name, 'w') for name in names]
     name2fh = dict([(fh.name, fh) for fh in fhs])
-    items = sorted([(key, len(f[key])) for key in f.keys()], 
+    items = sorted([(key, len(f[key])) for key in f.iterkeys()],
                    key=operator.itemgetter(1))
 
     l1 = len(items) - 1
@@ -212,6 +214,9 @@ def without_kmers(f, names):
         fh = fhs[l0 % len(fhs)]
         print_to_fh(fh, f, lens, items[l0])
 
+    for fh in fhs:
+        fh.close()
+
 
 def find_name_from_len(lmin, lens):
     """
